@@ -136,34 +136,6 @@ G_DEFINE_TYPE (GdmLaunchEnvironment, gdm_launch_environment, G_TYPE_OBJECT)
 static gboolean
 migrate_working_dir (GError **error)
 {
-        /* Makes sure GDM_WORKING_DIR has the right permissions and ownership.
-         * If it existed before the migration, g_mkdir_with_parents won't set
-         * the right mode. On some systems it'll be set to 0700 and gdm:gdm,
-         * which prevents the greeter session from accessing the subdirs within */
-        if (g_file_test (GDM_WORKING_DIR, G_FILE_TEST_IS_DIR)) {
-                if (g_chmod (GDM_WORKING_DIR, 0755) < 0) {
-                        int errsv = errno;
-                        g_set_error (error,
-                                     G_IO_ERROR,
-                                     g_io_error_from_errno (errsv),
-                                     "Failed to chmod directory '%s': %s",
-                                     GDM_WORKING_DIR,
-                                     g_strerror (errsv));
-                        return FALSE;
-                }
-
-                if (chown (GDM_WORKING_DIR, 0, 0) < 0) {
-                        int errsv = errno;
-                        g_set_error (error,
-                                     G_IO_ERROR,
-                                     g_io_error_from_errno (errsv),
-                                     "Failed to chown directory '%s': %s",
-                                     GDM_WORKING_DIR,
-                                     g_strerror (errsv));
-                        return FALSE;
-                }
-        }
-
         if (g_file_test (MIGRATED_STAMPFILE_PATH, G_FILE_TEST_EXISTS))
                 return TRUE;
 
@@ -178,6 +150,31 @@ migrate_working_dir (GError **error)
                 return FALSE;
         }
 
+        /* Make sure GDM_WORKING_DIR has the right permissions and ownership.
+         * If it existed before the migration, g_mkdir_with_parents won't set
+         * the right mode. On some systems it'll be set to 0700 and gdm:gdm,
+         * which prevents the greeter session from accessing the subdirs within */
+        if (g_chmod (GDM_WORKING_DIR, 0755) < 0) {
+                int errsv = errno;
+                g_set_error (error,
+                             G_IO_ERROR,
+                             g_io_error_from_errno (errsv),
+                             "Failed to chmod directory '%s': %s",
+                             GDM_WORKING_DIR,
+                             g_strerror (errsv));
+                return FALSE;
+        }
+        if (chown (GDM_WORKING_DIR, 0, 0) < 0) {
+                int errsv = errno;
+                g_set_error (error,
+                             G_IO_ERROR,
+                             g_io_error_from_errno (errsv),
+                             "Failed to chown directory '%s': %s",
+                             GDM_WORKING_DIR,
+                             g_strerror (errsv));
+                return FALSE;
+        }
+
         if (!gdm_copy_dir_recursively (GDM_WORKING_DIR "/.local/state",
                                        GDM_WORKING_DIR "/seat0/state",
                                        error)) {
@@ -270,7 +267,6 @@ static GHashTable *
 build_launch_environment (GdmLaunchEnvironment *launch_environment,
                           gboolean              start_session)
 {
-        gboolean is_initial_setup = FALSE;
         GHashTable    *hash;
         static const char *const optional_environment[] = {
                 "GI_TYPELIB_PATH",
@@ -320,9 +316,7 @@ build_launch_environment (GdmLaunchEnvironment *launch_environment,
                 g_hash_table_insert (hash, g_strdup ("GNOME_SHELL_SESSION_MODE"), g_strdup (launch_environment->session_mode));
                 g_hash_table_insert (hash, g_strdup ("DCONF_PROFILE"), g_strdup (launch_environment->dconf_profile));
 
-                is_initial_setup = strcmp (launch_environment->session_mode, INITIAL_SETUP_SESSION_MODE) == 0;
-
-                if (!is_initial_setup) {
+		if (strcmp (launch_environment->session_mode, INITIAL_SETUP_SESSION_MODE) != 0) {
 			/* gvfs is needed for fetching remote avatars in the initial setup. Disable it otherwise. */
 			g_hash_table_insert (hash, g_strdup ("GVFS_DISABLE_FUSE"), g_strdup ("1"));
 			g_hash_table_insert (hash, g_strdup ("GIO_USE_VFS"), g_strdup ("local"));
@@ -350,8 +344,7 @@ build_launch_environment (GdmLaunchEnvironment *launch_environment,
 
                 g_hash_table_insert (hash, g_strdup ("GDM_SEAT_ID"), g_strdup (seat_id));
 
-                if (!is_initial_setup &&
-                    setup_seat_persist_dirs(seat_id, launch_environment->dyn_uid, &config_dir, &state_dir)) {
+                if (setup_seat_persist_dirs(seat_id, launch_environment->dyn_uid, &config_dir, &state_dir)) {
                         g_hash_table_insert (hash, g_strdup ("XDG_CONFIG_HOME"), config_dir);
                         g_hash_table_insert (hash, g_strdup ("XDG_STATE_HOME"), state_dir);
                 }
